@@ -4,15 +4,15 @@ import io
 import pkg_resources
 from PIL import Image, ImageDraw, ImageFont, ImageOps
 
-WIDTH = 320
+WIDTH = 500
 HEIGHT = 90
-FONT_SIZE = 10
+FONT_SIZE = 16
 FONT = pkg_resources.resource_filename(__name__, 'resources/font.ttf')
 
 
 def draw_date(draw, date):
     font = ImageFont.truetype(FONT, FONT_SIZE)
-    draw.text((10, 60), u"Дата и время: " + date.strftime("%Y-%m-%d %H:%M:%S"), font=font, fill=(0, 0, 0))
+    draw.text((10, 55), u"Дата и время: " + date.strftime("%Y-%m-%d %H:%M:%S"), font=font, fill=(0, 0, 0))
 
 
 def draw_longstring(draw, name, position):
@@ -27,11 +27,10 @@ def draw_longstring(draw, name, position):
     draw.text(position, name, font=font, fill=(0, 0, 0))
 
 
-def convert(name, date, a_hash, position):
-    img_without_border = Image.new('RGB', (WIDTH, HEIGHT), color=(255, 255, 255))
-    img = ImageOps.expand(img_without_border, border=1, fill="black")
+def convert(name, date, a_hash, position, page_img):
+    sign_img = Image.new('RGBA', (WIDTH, HEIGHT), color=(255, 255, 255, 0))
 
-    d = ImageDraw.Draw(img)
+    d = ImageDraw.Draw(sign_img)
     draw_longstring(d, u"Подписано электронной подписью:", (10, 10))
     draw_longstring(d, name, (10, 25))
     if position != "":
@@ -39,8 +38,13 @@ def convert(name, date, a_hash, position):
     draw_date(d, date)
     draw_longstring(d, a_hash, (10, 70))
 
-    img_bytes = io.BytesIO()
-    im1 = img.convert('RGB')
-    im1.save(img_bytes, format='pdf')
-    img_bytes.seek(0)
-    return img_bytes
+    sign_img_bytes = io.BytesIO()
+    sign_img.save(sign_img_bytes, format='png')
+    sign_img_bytes.seek(0)
+
+    page_img.paste(sign_img, (0, page_img.size[1] - HEIGHT), sign_img)
+    page_img_bytes = io.BytesIO()
+    page_img.save(page_img_bytes, format='pdf')
+    page_img_bytes.seek(0)
+
+    return page_img_bytes
